@@ -1,5 +1,9 @@
 #![no_std]
+#![allow(clippy::expect_fun_call)]
 
+extern crate alloc;
+
+use alloc::format;
 use core::{any::type_name, convert::TryFrom, fmt::Debug};
 
 pub trait AssertInto<T>: Sized {
@@ -16,13 +20,10 @@ where
     #[inline]
     #[track_caller]
     fn assert_into(self) -> U {
-        U::try_from(self).unwrap_or_else(|err| {
-            panic!(
-                "{:?} is out of range for type {} ({:?})",
-                self,
-                type_name::<U>(),
-                err
-            );
-        })
+        U::try_from(self).expect(&format!(
+            "{:?} is out of range for type {}",
+            self,
+            type_name::<U>(),
+        ))
     }
 }
